@@ -1244,7 +1244,7 @@ gmw_about_activated_cb (GSimpleAction *action, GVariant *parameter, gpointer use
 	GList *windows;
 	GtkWindow *parent = NULL;
 	const gchar *authors[] = { "Richard Hughes", NULL };
-	const gchar *copyright = "Copyright \xc2\xa9 2014-2015 Richard Hughes";
+	const gchar *copyright = "Copyright \xc2\xa9 2014-2018 Richard Hughes";
 
 	windows = gtk_application_get_windows (GTK_APPLICATION (priv->application));
 	if (windows)
@@ -1260,7 +1260,7 @@ gmw_about_activated_cb (GSimpleAction *action, GVariant *parameter, gpointer use
 			       "comments", _("Write an ISO file to multiple USB devices at once"),
 			       "copyright", copyright,
 			       "license-type", GTK_LICENSE_GPL_2_0,
-			       "logo-icon-name", "gnome-multi-writer",
+			       "logo-icon-name", "org.gnome.MultiWriter",
 			       /* TRANSLATORS: you can put your name here :) */
 			       "translator-credits", _("translator-credits"),
 			       "version", VERSION,
